@@ -2,8 +2,11 @@ from grebble_flow.processors.base import BaseFlowProcessor
 
 
 class SimpleProcessor(BaseFlowProcessor):
-    name = "simple-flow-processor"
+    name = "simple-flow-base"
 
-    def execute(self, *args, **kwargs):
+    def execute(self, data, *args, **kwargs):
+        """
+        :param data: Default data description
+        """
         for i in range(0, 100):
             yield {"test": i}
